summaryrefslogtreecommitdiff
path: root/examples/stdkr_2d_bgk/step.hpp
diff options
context:
space:
mode:
authorClaudius "keldu" Holeksa <mail@keldu.de>2026-08-20 18:59:00 +0200
committerClaudius "keldu" Holeksa <mail@keldu.de>2026-08-20 18:59:00 +0200
commit5cd236287542b47016fe3c49aa56bb66d74c4ad7 (patch)
treea3eaf3b0419a1c5897c344a949cf5775b1637afc /examples/stdkr_2d_bgk/step.hpp
parent5dade743e7c1e6b0b6001b4265bf792f0b05f93a (diff)
downloadlibs-lbm-5cd236287542b47016fe3c49aa56bb66d74c4ad7.tar.gz
Feierabend
Diffstat (limited to 'examples/stdkr_2d_bgk/step.hpp')
-rw-r--r--examples/stdkr_2d_bgk/step.hpp3
1 files changed, 1 insertions, 2 deletions
diff --git a/examples/stdkr_2d_bgk/step.hpp b/examples/stdkr_2d_bgk/step.hpp
index 667f5a3..cbf9f43 100644
--- a/examples/stdkr_2d_bgk/step.hpp
+++ b/examples/stdkr_2d_bgk/step.hpp
@@ -17,13 +17,12 @@ saw::error_or<void> step(
auto& q = dev.get_handle();
auto& info_f = fields.template get<"info">();
- auto& porous_f = macros.template get<"porosity">();
{
q.submit([&](acpp::sycl::handler& h){
component<T,Desc,cmpt::BGK,encode::Sycl<saw::encode::Native>> collision{1.0};
component<T,Desc,cmpt::BounceBack,encode::Sycl<saw::encode::Native>> bb;
- component<T,Desc,cmpt::ZouHeHorizontal<false>,encode::Sycl<saw::encode::Native>> flow_out{1.0};
+ component<T,Desc,cmpt::ZouHePressureX<false>,encode::Sycl<saw::encode::Native>> flow_out{1.0};
h.parallel_for(acpp::sycl::range<Desc::D>{dim_x,dim_y}, [=](acpp::sycl::id<Desc::D> idx){
saw::data<sch::FixedArray<sch::UInt64,Desc::D>> index;